#!/usr/bin/env python
# -*- coding: utf-8 -*-

# file      : fconfig.py
# project   : fricorder
# copyright : (C) 2013 by Claude Bulin
#
# This file is part of fricorder project
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; version 3.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA


import os
import sys


class FConfig:

	#================================================================
	# name of package
	#================================================================
	__PACKAGE__ = "fricorder"
	#================================================================
	# version numero
	#================================================================
	__VERSION__ = "0.8.2"
	#================================================================
	# authors
	#================================================================
	__AUTHOR__  = "Claude BULIN"
	#================================================================
	# adr mail
	#================================================================
	__MAIL__    = "xcfaudio@gmail.com"
	#================================================================
	# url
	#================================================================
	__URL__    = "http://www.xcfa.tuxfamily.org/article23/fricorder"

	#================================================================
	# def du repertoire de cache (pid/halt file et progtv.data)
	#================================================================
	# attention, le suivant doit correspondre a celui egalement utilise
	# dans frecord.sh
	CACHEDIR = os.getenv("XDG_CACHE_HOME",
						   os.path.join(os.getenv("HOME"), ".cache", "fricorder")
						)

	if not os.path.isdir(CACHEDIR):
		os.makedirs(CACHEDIR)

	#================================================================
	# def du fichier de config de fricorder
	#================================================================
	CONFIGFILE = os.getenv("XDG_CONFIG_HOME",
						   os.path.join(os.getenv("HOME"), ".config", "fricorder")
						   )

	if not os.path.isdir(CONFIGFILE):
		os.makedirs(CONFIGFILE)

	#================================================================
	# def du repertoire contenant les data de fricorder
	#================================================================
	DATADIR = os.path.join( os.path.dirname(__file__),"data")
	if not os.path.isdir(DATADIR):
		DATADIR = "/usr/share/fricorder"

	#================================================================
	# def du repertoire contenant les sources de fricorder
	#================================================================
	SRCDIR = os.path.join( os.path.dirname(__file__),"src")
	if os.path.isdir(SRCDIR):
		sys.path.append(SRCDIR)
	else:
		SRCDIR = "/usr/share/fricorder"
		sys.path.append(SRCDIR)

	#================================================================
	# def du repertoire contenant les traductions de fricorder
	#================================================================
	LOCALE_DIR  = os.path.join( os.path.dirname(__file__),"po")
	if os.path.isdir(LOCALE_DIR):
		sys.path.append(LOCALE_DIR)
	else:
		LOCALE_DIR = "/usr/share/locale/"
		sys.path.append(LOCALE_DIR)
	sys.path.append("/usr/share/locale/")

	def print_FConfig():
		print('')
		print('CACHEDIR   ', FConfig.CACHEDIR)
		print('CONFIGFILE ', FConfig.CONFIGFILE)
		print('DATADIR    ', FConfig.DATADIR)
		print('SRCDIR     ', FConfig.SRCDIR)
		print('LOCALE_DIR ', FConfig.LOCALE_DIR)

