#!/usr/bin/env python
# -*- coding: utf-8 -*-

# file      : Language_Init.py
# project   : fricorder
# copyright : (C) 2013 by Claude Bulin
#
# This file is part of fricorder project
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; version 3.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
#
# This file from to:
# OpenShot Video Editor is a program that creates, modifies, and edits video files.
# Copyright (C) 2009  Jonathan Thomas
#
# Source file modiffied to: fricorder


# ----------------------------- EXAMPLE CODE
#
# Use this snippet on any module that needs to support translations.  Once this
# snippet is in place, you can use the _("") method to set all your strings.
#
#	 import language.Language_Init as Language_Init
#
#	 # Add this to each method that needs to translate strings
#	 _ = Language_Init.Translator().lang.gettext
#
#	 # To mark a string as 'translatable', use this syntax:
#	 MyString = _("Here is my string")
#
# ----------------------------- GENERATE THE POT FILE
#
# Use ppt.py
# http://www.xcfa.tuxfamily.org/article22/python-project-translating
#
# Example:  $ ppt.py -g
#
# -----------------------------


# import modules needed for language translation & gtk support
from gi.repository import Gtk
import os, sys
import gettext, locale


########################################################################
class Translator:
	"""Class that contains functions to initiate language translations"""

	#----------------------------------------------------------------------
	def __init__(self, project):
		"""Constructor"""

		self.project = project

		# Setup foreign language support
		langs = []
		lc, encoding = locale.getlocale(locale.LC_MESSAGES)

		if (lc):
			langs = [lc]

		# Add by xcfaudio: complementary xx from xx_XX
		if len(lc) == 5:
			str_lang = lc[0:2]
			if str_lang not in langs:
				langs.append( str_lang )

		language = os.environ.get('LANGUAGE', None)
		if (language):
			langs += language.split(":")

		# Set locale specific settings
		locale.setlocale(locale.LC_ALL)
		locale.bindtextdomain("fricorder", self.project.LOCALE_DIR)
		locale.bind_textdomain_codeset("fricorder", "UTF-8")

		# Set gettext settings
		gettext.bindtextdomain("fricorder", self.project.LOCALE_DIR)
		gettext.bind_textdomain_codeset("fricorder", "UTF-8")
		gettext.textdomain("fricorder")
		gettext.install(domain="fricorder", localedir=self.project.LOCALE_DIR)

		# This reference is used by other classes to define the _ method
		self.lang = gettext.translation("fricorder", self.project.LOCALE_DIR, languages = langs, fallback = True)
