#!/usr/bin/env python
# -*- coding: utf-8 -*-

# file      : messagebox.py
# project   : fricorder
# copyright : (C) 2013 by Claude Bulin
# 
# This file is part of fricorder project
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; version 3.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
#
# This file from to:
# OpenShot Video Editor is a program that creates, modifies, and edits video files.
# Copyright (C) 2009  Jonathan Thomas
#
# Source file modiffied to: fricorder


from gi.repository import Gtk
import os, sys
from fconfig import FConfig
# init the foreign language
import Language_Init
_ = Language_Init.Translator(FConfig).lang.gettext


def get_response(*args):
	
	# look for extra parameters
	parameters = None
	for arg in args:
		if type(arg) == dict:
			parameters = arg
			break
	
	# hide message dialog
	args[0].destroy()

	if args[1] == Gtk.ResponseType.OK:
		# call callback function (if any)
		if args[2]:
			# call callback
			if parameters:
				args[2](parameters)
			else:
				args[2]()
	elif args[1] == Gtk.ResponseType.CANCEL:
		# call callback function (if any)
		if args[3]:
			# call callback
			if parameters:
				args[3](parameters)
			else:
				args[3]()
	else:
		pass
		

# show an error message (i.e. GtkDialog)
def show(title, error_message, buttons=Gtk.ButtonsType.OK, yes_callback_function=None, no_callback_function=None, dialog_type=Gtk.MessageType.QUESTION, secondary_message=None, *args):

	# parse out any dictionaries (needed for custom parameters)
	button_list = []
	parameters = None
	buttonA = None
	buttonB = None
	for arg in args:
		if not type(arg) == dict:
			if buttonA == None:
				buttonA = arg
			elif buttonB == None:
				buttonB = arg
				button_list.append((buttonA, buttonB))
				buttonA = None
				buttonB = None
		else:
			parameters = arg

	# create an error message dialog
	dialog = Gtk.MessageDialog(
		parent		 = None,
		flags		 = Gtk.DialogFlags.MODAL,
		type		 = dialog_type,
		buttons		 = buttons,
		message_format = error_message)
	dialog.set_title(title)
	dialog.format_secondary_text(secondary_message)
	
	for button in button_list:
		dialog.add_button(button[0], button[1])
	
	#if getIconPath("openshot"):
		#dialog.set_icon_from_file(getIconPath("openshot"))
		
	dialog.connect('response', get_response, yes_callback_function, no_callback_function, parameters)
	dialog.show()




